@@ -19,7 +19,18 @@ correlation.formula <- function (formula, data = NULL, subset, na.action, ...)
     mf$... <- NULL
     mf[[1L]] <- as.name("model.frame")
     mf <- eval.parent(mf)
-    if (stats:::.check_vars_numeric(mf)) 
+    
+	## Copied from stats:::.check_vars_numeric()
+	.check_vars_numeric <- function (mf) {
+	    mt <- attr(mf, "terms")
+	    mterms <- attr(mt, "factors")
+	    mterms <- rownames(mterms)[apply(mterms, 1L, function(x) any(x > 
+	        0L))]
+	    any(sapply(mterms, function(x) is.factor(mf[, x]) || !is.numeric(mf[, 
+	        x])))
+	}
+
+	if (.check_vars_numeric(mf)) 
         stop("Correlation applies only to numerical variables")
     mt <- attr(mf, "terms")
     attr(mt, "intercept") <- 0L
@@ -45,7 +56,7 @@ method = c("pearson", "kendall", "spearman"), ...)
 	method <- match.arg(method)
 	
 	## Just call cor in stats package
-	res <- stats:::cor(x = x, y = y, use = use, method = method)
+	res <- stats::cor(x = x, y = y, use = use, method = method)
 	
 	## We want to return a correlation matrix, even if there is one correlation
 	if (length(res) == 1) {
